pub enum FirewallError {
Show 13 variants
InvalidDportValue(usize, String),
InvalidSportValue(usize, String),
InvalidDestValue(usize, String),
InvalidSourceValue(usize, String),
InvalidIcmpTypeValue(usize, String),
InvalidProtocolValue(usize, String),
InvalidDirection(usize, String),
InvalidAction(usize, String),
UnknownOption(usize, String),
EmptyOption(usize, String),
DuplicatedOption(usize, String),
NotEnoughArguments(usize),
NotApplicableIcmpType(usize),
}Expand description
Error that may arise as a consequence of an invalid firewall specification.
Variants
InvalidDportValue(usize, String)
The value supplied for the option --dport is invalid.
InvalidSportValue(usize, String)
The value supplied for the option --sport is invalid.
InvalidDestValue(usize, String)
The value supplied for the option --dest is invalid.
InvalidSourceValue(usize, String)
The value supplied for the option --source is invalid.
InvalidIcmpTypeValue(usize, String)
The value supplied for the option --icmp-type is invalid.
InvalidProtocolValue(usize, String)
The value supplied for the option --proto is invalid.
InvalidDirection(usize, String)
An invalid direction has been specified for a firewall rule.
InvalidAction(usize, String)
An invalid action has been specified for a firewall rule.
UnknownOption(usize, String)
An unknown option has been specified for a firewall rule.
EmptyOption(usize, String)
An empty option has been specified for a firewall rule.
DuplicatedOption(usize, String)
The same option has been specified multiple times for the same firewall rule.
NotEnoughArguments(usize)
Not enough arguments have been specified for a firewall rule.
NotApplicableIcmpType(usize)
The option --icmp-type is valid only if --proto 1 or --proto 58 is also specified.